====
TODO
====

* Increase test coverage.
* :mod:`pydl.pydlutils.mangle` needs more work.

  - Area (solid angle) calculation.
  - Area calculation needs to account for the
    ``use_caps`` attribute.
  - Intersection of caps with other caps.
